@@ -1,8 +1,8 @@
 # Licensed under the terms of http://www.apache.org/licenses/LICENSE-2.0
 # Author (©): Alvaro del Castillo
 
-from mcthings.world import World
 from mcthings.thing import Thing
+from mcthings.world import World
 
 
 class Circle(Thing):
@@ -11,7 +11,7 @@ class Circle(Thing):
     """ radius of the Sphere """
 
     def build(self):
-        World.drawing.drawCircle(
+        World.renderer.server.drawing.drawCircle(
             self.position.x,
             self.position.y,
             self.position.z,
