@@ -17,7 +17,7 @@ class Town(Thing):
     space = 3
     """space between the town houses"""
 
-    def build(self):
+    def create(self):
 
         init_x = self.position.x
         init_y = self.position.y
@@ -33,7 +33,7 @@ class Town(Thing):
             house.height = self.house_height
             house.block = self.block
             house.mirror = self.house_mirror
-            house.build()
+            house.create()
             house_pos.z += self.house_width + self.space
 
         # Fill the end_position
